@@ -21,8 +21,8 @@
 #ifndef KNEWSTUFF3_KNEWSTUFFENTRY_H
 #define KNEWSTUFF3_KNEWSTUFFENTRY_H
 
-#include <QtCore/QStringList>
-#include <QtCore/QSharedDataPointer>
+#include <QStringList>
+#include <QSharedDataPointer>
 #include <QLoggingCategory>
 
 #include "knewstuff_export.h"
@@ -126,7 +126,7 @@ public:
 
     /**
      * Id of this Entry. It is guaranteed to be unique for one provider.
-     * Id and ProviderId together identifiy this entry.
+     * Id and ProviderId together identify this entry.
      * @return the id
      * @since 4.5
      */
